==> arepy-0.2.4-py3-none-any.whl: arepy/engine/renderer/renderer_2d.py <==
from os import PathLike
from typing import Optional, Protocol

from ...bundle.components.camera_component import Camera2D
from . import ArepyTexture, Color, Rect, TextureFilter


class Renderer2D(Protocol):
    # Texture methods
    def create_render_texture(self, width: int, height: int) -> ArepyTexture: ...
    def create_texture(self, path: PathLike[str]) -> ArepyTexture: ...
    def unload_texture(self, texture: ArepyTexture) -> None: ...

    # Draw methods
    def bind_render_texture(self, texture: ArepyTexture) -> None: ...
    def unbind_render_texture(self) -> None: ...
    def draw_texture(
        self, texture: ArepyTexture, source: Rect, dest: Rect, color: Color
    ) -> None: ...
    def draw_texture_ex(
        self,
        texture: ArepyTexture,
        source: Rect,
        dest: Rect,
        origin: tuple[float, float],
        rotation: float,
        color: Color,
    ) -> None: ...
    def draw_rectangle(self, rect: Rect, color: Color) -> None: ...
    def draw_rectangle_ex(self, rect: Rect, rotation: float, color: Color) -> None: ...
    def draw_unfilled_rectangle(self, rect: Rect, color: Color) -> None: ...
    def draw_points(self, points: list[tuple[float, float]], color: Color) -> None: ...
    def draw_lines(self, points: list[tuple[float, float]], color: Color) -> None: ...
    def draw_circle(
        self, center: tuple[float, float], radius: float, color: Color
    ) -> None: ...

    def draw_text(
        self, text: str, position: tuple[float, float], font_size: int, color: Color
    ) -> None: ...
    def draw_fps(
        self,
        position: tuple[int, int],
    ) -> None: ...
    def screen_to_world(
        self, position: tuple[float, float], camera: Camera2D
    ) -> tuple[float, float]: ...

    # Frame methods
    def set_texture_filter(
        self, texture: ArepyTexture, filter: TextureFilter
    ) -> None: ...
    def set_max_framerate(self, max_frame_rate: int) -> None: ...
    def clear(self, color: Color) -> None: ...
    def start_frame(self) -> None: ...
    def end_frame(self) -> None: ...
    def flush(self) -> None: ...
    def swap_buffers(self) -> None: ...
    def get_delta_time(self) -> float: ...
    def get_framerate(self) -> int: ...

    # Camera methods
    def add_camera(self, camera: Camera2D) -> None: ...
    def get_camera(self, id: int) -> Optional[Camera2D]: ...
    def remove_camera(self, id: int) -> None: ...
    def begin_camera_mode(self, camera: Camera2D) -> None: ...
    def end_camera_mode(self) -> None: ...
    def update_camera(self, camera: Camera2D) -> None: ...
    @property
    def cameras(self) -> list[Camera2D]: ...
    @property
    def current_camera(self) -> Camera2D: ...

==> arepy-0.3.0-py3-none-any.whl: arepy/engine/renderer/renderer_2d.py <==
from os import PathLike
from typing import Optional, Protocol

from ...bundle.components.camera import Camera2D
from . import ArepyTexture, Color, Rect, TextureFilter


class Renderer2D(Protocol):
    # Texture methods
    def create_render_texture(self, width: int, height: int) -> ArepyTexture: ...
    def create_texture(self, path: PathLike[str]) -> ArepyTexture: ...
    def unload_texture(self, texture: ArepyTexture) -> None: ...

    # Draw methods
    def bind_render_texture(self, texture: ArepyTexture) -> None: ...
    def unbind_render_texture(self) -> None: ...
    def draw_texture(
        self, texture: ArepyTexture, source: Rect, dest: Rect, color: Color
    ) -> None: ...
    def draw_texture_ex(
        self,
        texture: ArepyTexture,
        source: Rect,
        dest: Rect,
        origin: tuple[float, float],
        rotation: float,
        color: Color,
    ) -> None: ...
    def draw_rectangle(self, rect: Rect, color: Color) -> None: ...
    def draw_rectangle_ex(self, rect: Rect, rotation: float, color: Color) -> None: ...
    def draw_unfilled_rectangle(self, rect: Rect, color: Color) -> None: ...
    def draw_points(self, points: list[tuple[float, float]], color: Color) -> None: ...
    def draw_lines(self, points: list[tuple[float, float]], color: Color) -> None: ...
    def draw_circle(
        self, center: tuple[float, float], radius: float, color: Color
    ) -> None: ...

    def draw_text(
        self, text: str, position: tuple[float, float], font_size: int, color: Color
    ) -> None: ...
    def draw_fps(
        self,
        position: tuple[int, int],
    ) -> None: ...
    def screen_to_world(
        self, position: tuple[float, float], camera: Camera2D
    ) -> tuple[float, float]: ...

    # Frame methods
    def set_texture_filter(
        self, texture: ArepyTexture, filter: TextureFilter
    ) -> None: ...
    def set_max_framerate(self, max_frame_rate: int) -> None: ...
    def clear(self, color: Color) -> None: ...
    def start_frame(self) -> None: ...
    def end_frame(self) -> None: ...
    def flush(self) -> None: ...
    def swap_buffers(self) -> None: ...
    def get_delta_time(self) -> float: ...
    def get_framerate(self) -> int: ...

    # Camera methods
    def add_camera(self, camera: Camera2D) -> None: ...
    def get_camera(self, id: int) -> Optional[Camera2D]: ...
    def remove_camera(self, id: int) -> None: ...
    def begin_camera_mode(self, camera: Camera2D) -> None: ...
    def end_camera_mode(self) -> None: ...
    def update_camera(self, camera: Camera2D) -> None: ...
    def get_cameras(self) -> list[Camera2D]: ...
    def get_current_camera(self) -> Camera2D: ...
    def disable_mouse_cursor(self) -> None: ...
    def enable_mouse_cursor(self) -> None: ...
    def is_mouse_cursor_hidden(self) -> bool: ...
    def set_mouse_position(self, position: tuple[float, float]) -> None: ...
